@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration
 
-our $VERSION = '0.0103';
+our $VERSION = '0.0200';
 
 use Moo;
 use strictures 2;
@@ -42,19 +42,19 @@ has pool => (
 );
 
 
-has threshold => (
+has min_size => (
     is       => 'ro',
     builder  => 1,
     lazy     => 1,
     init_arg => undef,
 );
 
-sub _build_threshold {
+sub _build_min_size {
     my ($self) = @_;
 
     my @sizes = map { $self->duration($_) } @{ $self->pool };
 
-    return ( $self->size - min(@sizes) ) - ( $self->size - 1 );
+    return min(@sizes);
 }
 
 
@@ -81,14 +81,16 @@ sub motif {
         my $name = $self->pool->[ int rand @{ $self->pool } ];
         my $size = $self->duration($name);
         my $diff = $self->size - $sum;
+        last
+            if $diff < $self->min_size;
         next
             if $size > $diff;
         $sum += $size;
-#warn(__PACKAGE__,' ',__LINE__," MARK: $name, $size, ",$sum,"\n");
+#warn(__PACKAGE__,' ',__LINE__," MARK: $name, $size, $sum\n");
         push @$motif, $name
             if $sum <= $self->size;
         last
-            if $sum > $self->size - 1 + $self->threshold;
+            if $sum >= $self->size;
     }
 
     return $motif;
@@ -108,7 +110,7 @@ Music::Duration::Partition - Partition a musical duration
 
 =head1 VERSION
 
-version 0.0103
+version 0.0200
 
 =head1 SYNOPSIS
 
@@ -172,9 +174,9 @@ motif.
 
 Default: C<[ keys %MIDI::Simple::Length ]>
 
-=head2 threshold
+=head2 min_size
 
-  $threshold = $mdp->threshold;
+  $min_size = $mdp->min_size;
 
 This is a computed attribute.
 
